import React, { forwardRef, useContext } from 'react';
import { IconContext } from '../lib/index.esm.js';
import { objectWithoutPropertiesLoose as _objectWithoutPropertiesLoose } from '../_virtual/_rollupPluginBabelHelpers.js';

var renderPathFor = function renderPathFor(weight, color) {
  switch (weight) {
    case "bold":
      return React.createElement(React.Fragment, null, React.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "24",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React.createElement("circle", {
        cx: "96",
        cy: "84",
        r: "16"
      }), React.createElement("circle", {
        cx: "160",
        cy: "84",
        r: "16"
      }), React.createElement("circle", {
        cx: "96",
        cy: "128",
        r: "16"
      }), React.createElement("circle", {
        cx: "160",
        cy: "128",
        r: "16"
      }), React.createElement("circle", {
        cx: "96",
        cy: "172",
        r: "16"
      }), React.createElement("circle", {
        cx: "160",
        cy: "172",
        r: "16"
      }));

    case "duotone":
      return React.createElement(React.Fragment, null, React.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        opacity: "0.2"
      }), React.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React.createElement("circle", {
        cx: "92",
        cy: "84",
        r: "12"
      }), React.createElement("circle", {
        cx: "164",
        cy: "84",
        r: "12"
      }), React.createElement("circle", {
        cx: "92",
        cy: "128",
        r: "12"
      }), React.createElement("circle", {
        cx: "164",
        cy: "128",
        r: "12"
      }), React.createElement("circle", {
        cx: "92",
        cy: "172",
        r: "12"
      }), React.createElement("circle", {
        cx: "164",
        cy: "172",
        r: "12"
      }));

    case "fill":
      return React.createElement(React.Fragment, null, React.createElement("path", {
        d: "M192,32H64A32.03667,32.03667,0,0,0,32,64V192a32.03667,32.03667,0,0,0,32,32H192a32.03667,32.03667,0,0,0,32-32V64A32.03667,32.03667,0,0,0,192,32ZM92,184a12,12,0,1,1,12-12A12,12,0,0,1,92,184Zm0-44a12,12,0,1,1,12-12A12,12,0,0,1,92,140Zm0-44a12,12,0,1,1,12-12A12,12,0,0,1,92,96Zm72,88a12,12,0,1,1,12-12A12,12,0,0,1,164,184Zm0-44a12,12,0,1,1,12-12A12,12,0,0,1,164,140Zm0-44a12,12,0,1,1,12-12A12,12,0,0,1,164,96Z"
      }));

    case "light":
      return React.createElement(React.Fragment, null, React.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "12",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React.createElement("circle", {
        cx: "92",
        cy: "84",
        r: "10"
      }), React.createElement("circle", {
        cx: "164",
        cy: "84",
        r: "10"
      }), React.createElement("circle", {
        cx: "92",
        cy: "128",
        r: "10"
      }), React.createElement("circle", {
        cx: "164",
        cy: "128",
        r: "10"
      }), React.createElement("circle", {
        cx: "92",
        cy: "172",
        r: "10"
      }), React.createElement("circle", {
        cx: "164",
        cy: "172",
        r: "10"
      }));

    case "thin":
      return React.createElement(React.Fragment, null, React.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "8",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React.createElement("circle", {
        cx: "92",
        cy: "84",
        r: "8"
      }), React.createElement("circle", {
        cx: "164",
        cy: "84",
        r: "8"
      }), React.createElement("circle", {
        cx: "92",
        cy: "128",
        r: "8"
      }), React.createElement("circle", {
        cx: "164",
        cy: "128",
        r: "8"
      }), React.createElement("circle", {
        cx: "92",
        cy: "172",
        r: "8"
      }), React.createElement("circle", {
        cx: "164",
        cy: "172",
        r: "8"
      }));

    case "regular":
      return React.createElement(React.Fragment, null, React.createElement("rect", {
        x: "40",
        y: "40",
        width: "176",
        height: "176",
        rx: "24",
        strokeWidth: "16",
        stroke: color,
        strokeLinecap: "round",
        strokeLinejoin: "round",
        fill: "none"
      }), React.createElement("circle", {
        cx: "92",
        cy: "84",
        r: "12"
      }), React.createElement("circle", {
        cx: "164",
        cy: "84",
        r: "12"
      }), React.createElement("circle", {
        cx: "92",
        cy: "128",
        r: "12"
      }), React.createElement("circle", {
        cx: "164",
        cy: "128",
        r: "12"
      }), React.createElement("circle", {
        cx: "92",
        cy: "172",
        r: "12"
      }), React.createElement("circle", {
        cx: "164",
        cy: "172",
        r: "12"
      }));

    default:
      console.error('Unsupported icon weight. Choose from "thin", "light", "regular", "bold", "fill", or "duotone".');
      return null;
  }
};

var DiceSix = /*#__PURE__*/forwardRef(function (props, ref) {
  var color = props.color,
      size = props.size,
      weight = props.weight,
      mirrored = props.mirrored,
      children = props.children,
      restProps = _objectWithoutPropertiesLoose(props, ["color", "size", "weight", "mirrored", "children"]);

  var _useContext = useContext(IconContext),
      contextColor = _useContext.color,
      contextSize = _useContext.size,
      contextWeight = _useContext.weight,
      contextMirrored = _useContext.mirrored,
      restContext = _objectWithoutPropertiesLoose(_useContext, ["color", "size", "weight", "mirrored"]);

  return React.createElement("svg", Object.assign({
    ref: ref,
    xmlns: "http://www.w3.org/2000/svg",
    width: size != null ? size : contextSize,
    height: size != null ? size : contextSize,
    fill: color != null ? color : contextColor,
    viewBox: "0 0 256 256",
    transform: mirrored || contextMirrored ? "scale(-1, 1)" : undefined
  }, restContext, restProps), children, React.createElement("rect", {
    width: "256",
    height: "256",
    fill: "none"
  }), renderPathFor(weight != null ? weight : contextWeight, color != null ? color : contextColor));
});
DiceSix.displayName = "DiceSix";

export default DiceSix;
//# sourceMappingURL=DiceSix.esm.js.map
